Trait DecisionSpace

pub trait DecisionSpace<'a, T> {
    // Required method
    fn within(&self, x: &T) -> bool;
}
Abstract definition of a decision space which is defined by which points lie within and which points lie outside it.

Required Methods

fn within(&self, x: &T) -> bool

Checks whether the given configuration is within the decision space.

Implementations on Foreign Types

Source

impl<'a, T> DecisionSpace<'_, Config<T>> for Vec<(T, T)>
where T: Value<'a>,

Source

fn within(&self, x: &Config<T>) -> bool

Source

impl<'a, T> DecisionSpace<'_, Config<T>> for Vec<T>
where T: Value<'a>,

Source

fn within(&self, x: &Config<T>) -> bool

Implementors

Source

impl<'a, T, U> DecisionSpace<'a, T> for U
where T: Value<'a>, U: Value<'a>,