pub enum EnergyConsumptionModel {
Linear(HashMap<String, LinearEnergyConsumptionModel>),
SimplifiedLinear(HashMap<String, SimplifiedLinearEnergyConsumptionModel>),
NonLinear(HashMap<String, NonLinearEnergyConsumptionModel>),
}Expand description
Energy consumption model. Parameters are provided separately for each server type.
Variants
Linear(HashMap<String, LinearEnergyConsumptionModel>)
Linear model from Dayarathna et al.
SimplifiedLinear(HashMap<String, SimplifiedLinearEnergyConsumptionModel>)
Simplification of the linear model with the assumption that servers consume half of their peak power when idling.
NonLinear(HashMap<String, NonLinearEnergyConsumptionModel>)
Non-linear model from Dayarathna et al.
Implementations
Sourceimpl EnergyConsumptionModel
impl EnergyConsumptionModel
Sourcepub fn consumption(&self, delta: f64, server_type: &ServerType, s: N64) -> N64
pub fn consumption(&self, delta: f64, server_type: &ServerType, s: N64) -> N64
Energy consumption of a server of some type with utilization $s$. Referred to as $\phi$ in the paper.