Struct Schedule

pub struct Schedule<T>(/* private fields */);
Includes all configurations from time $1$ to time $t_end$.

Implementations

Source

impl<'a, T> Schedule<T>
where T: Value<'a>,

pub fn new(x: Vec<Config<T>>) -> Schedule<T>

Converts a vector of configurations to a schedule.

pub fn empty() -> Schedule<T>

Builds an empty schedule.

pub fn repeat(x: Config<T>, t: i32) -> Schedule<T>

pub fn is_empty(&self) -> bool

Returns true if the schedule is empty (i.e. does not include any config).

pub fn t_end(&self) -> i32

Returns the time of the latest time step.

pub fn now(&self) -> Config<T>

Returns the config of the latest time step.

pub fn now_with_default(&self, default: Config<T>) -> Config<T>

Returns the config of the latest time step.

pub fn get(&self, t: i32) -> Option<&Config<T>>

Returns the config at time $t$ if present.

pub fn shift(&mut self, x: Config<T>)

Extends schedule with a new initial config.

pub fn push(&mut self, x: Config<T>)

Extends schedule with a new final config.

pub fn extend(&self, x: Config<T>) -> Schedule<T>

Immutably Extends schedule with a new final config.

pub fn skip(&self, delta: i32) -> Self

Skips first $delta$ configurations.

pub fn to_vec(&self) -> Vec<Vec<T>>

Converts schedule to a vector of vectors.

pub fn from_raw(d: i32, w: i32, raw_xs: &[T]) -> Schedule<T>

Builds a schedule from a raw (flat) encoding $raw_xs$ (used for convex optimization). $d$ is the number of dimensions, $w$ is the length of the time window. The length of $raw_xs$ must therefore be $d \cdot w$.

pub fn build_raw(w: i32, x: &Config<T>) -> Vec<T>

Builds a raw (flat) encoding of a schedule (used for convex optimization) by stretching a config across the time window $w$.

pub fn raw_encoding_len(d: i32, w: i32) -> i32

Returns the length of the raw encoding of $d$ dimensions across time window $w$.

Source

impl<'a, T> Schedule<T>
where T: Value<'a>,

pub fn verify(&self, t_end: i32, bounds: &Vec<T>) -> Result<()>