pub trait DecisionSpace<'a, T> {
// Required method
fn within(&self, x: &T) -> bool;
}Expand description
Abstract definition of a decision space which is defined by which points lie within and which points lie outside it.
pub trait DecisionSpace<'a, T> {
// Required method
fn within(&self, x: &T) -> bool;
}Abstract definition of a decision space which is defined by which points lie within and which points lie outside it.