pub type IntegralSmoothedLoadOptimization = SmoothedLoadOptimization<i32>;Aliased Type
struct IntegralSmoothedLoadOptimization {
pub d: i32,
pub t_end: i32,
pub bounds: Vec<i32>,
pub switching_cost: Vec<f64>,
pub hitting_cost: Vec<f64>,
pub load: Vec<i32>,
}Fields
d: i32Number of dimensions.
t_end: i32Finite, positive time horizon.
bounds: Vec<i32>Vector of upper bounds of each dimension.
switching_cost: Vec<f64>Vector of positive real constants resembling the switching cost of each dimension (strictly ascending). Dimensions must be efficient, i.e. there must not be dimensions with a higher switching and higher hitting cost than onether dimension.
hitting_cost: Vec<f64>Time-independent cost of each dimension (strictly descending).
load: Vec<i32>Non-negative load at each time step.