pub struct Schedule<T>(/* private fields */);Expand description
Includes all configurations from time $1$ to time $t_end$.
Implementations
Sourceimpl<'a, T> Schedule<T>where
T: Value<'a>,
impl<'a, T> Schedule<T>where
T: Value<'a>,
Sourcepub fn new(x: Vec<Config<T>>) -> Schedule<T>
pub fn new(x: Vec<Config<T>>) -> Schedule<T>
Converts a vector of configurations to a schedule.
pub fn repeat(x: Config<T>, t: i32) -> Schedule<T>
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the schedule is empty (i.e. does not include any config).
Sourcepub fn now_with_default(&self, default: Config<T>) -> Config<T>
pub fn now_with_default(&self, default: Config<T>) -> Config<T>
Returns the config of the latest time step.
Sourcepub fn extend(&self, x: Config<T>) -> Schedule<T>
pub fn extend(&self, x: Config<T>) -> Schedule<T>
Immutably Extends schedule with a new final config.
Sourcepub fn from_raw(d: i32, w: i32, raw_xs: &[T]) -> Schedule<T>
pub fn from_raw(d: i32, w: i32, raw_xs: &[T]) -> Schedule<T>
Builds a schedule from a raw (flat) encoding $raw_xs$ (used for convex optimization). $d$ is the number of dimensions, $w$ is the length of the time window. The length of $raw_xs$ must therefore be $d \cdot w$.
Sourcepub fn build_raw(w: i32, x: &Config<T>) -> Vec<T>
pub fn build_raw(w: i32, x: &Config<T>) -> Vec<T>
Builds a raw (flat) encoding of a schedule (used for convex optimization) by stretching a config across the time window $w$.
Sourcepub fn raw_encoding_len(d: i32, w: i32) -> i32
pub fn raw_encoding_len(d: i32, w: i32) -> i32
Returns the length of the raw encoding of $d$ dimensions across time window $w$.